@@ -1,7 +1,12 @@
 import os, tempfile
+import pkgutil
 import requests
 
 
+def get_resource(file):
+    return pkgutil.get_data(__name__, file)
+
+
 def download_file(uri):
     r = requests.get(uri)
     if r.status_code == 200:
